@@ -29,9 +29,6 @@ public:
     //! Destructor.
     virtual ~ButtonSelectDlg();
 
-protected:
-    virtual void changeEvent(QEvent *e);
-
 private:
     Ui::ButtonSelectDlg *m_ui;
     //! Stringlist for theme directories.
@@ -57,11 +54,14 @@ private:
 
     bool defaultflag;
 
+	QString fileNameUnPressed;
+    QString fileNamePressed;
+    QString confFileName;
 private slots:
     //! Emits button filenames and config filename to NewButtonDlg class.
     void on_selectPushButton_clicked();
 
-    void setBackgroundsOnListWidget2(QListWidgetItem *item);
+    void setButtonsOnListWidget2(QListWidgetItem *item);
     //! Sets button pixmap to preview label.
     void setButton();
 
