@@ -141,7 +141,7 @@ void CommandChainDlg::deleteRemote()
             deviceList.append(line);
         }
         for(int i = 0; i<deviceList.count();i++) {
-            if(deviceList.at(i) =="include \"/home/user/MyDocs/qtirreco/Devices/" + remoteName +"\"")
+            if(deviceList.at(i) =="include \"" + devicesPath + remoteName +"\"")
             deviceList.removeAt(i);
         }
         LircConfFile.close();
