@@ -46,7 +46,7 @@ private:
 
 signals:
     //! Adds command to NewButtonDlg and closes this.
-    void signalAddCommand(const QString &commandName,const QString &modelName);
+    void signalAddCommand(QString commandName,QString modelName);
 
 private slots:
     //! Opens DownloadRemoteDlg.
