@@ -18,7 +18,7 @@ DownloadRemoteDlg::DownloadRemoteDlg(QWidget *parent, bool remoteStartupOnOff, Q
     client = new QxtXmlRpcClient(this, url);
     connect(client,SIGNAL(finish(int,QVariant)),this,SLOT(processReturnValue(int,QVariant)));
     connect(client,SIGNAL(networkError(int,QString)),this,SLOT(error(int,QString)));
-    connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString)));
+    connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString )));
     QList<QVariant> list;
     list.clear();
     alphabeticalId = client->call("getLircDirs",list);
@@ -79,16 +79,16 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
         m_ui->remoteList->clear();
         m_ui->alphabeticalList->insertItems(0,sList);
     }
-    if (Id == manufacturerId) {
+    else if (Id == manufacturerId) {
         m_ui->manufacturerList->clear();
         m_ui->remoteList->clear();
         m_ui->manufacturerList->insertItems(0,sList);
     }
-    if (Id == modelId) {
+    else if (Id == modelId) {
         m_ui->remoteList->clear();
         m_ui->remoteList->insertItems(0,sList);
     }
-    if (Id == fileId) {
+    else if (Id == fileId) {
         QDir dir;
         if(!dir.exists(devicesPath))
             dir.mkpath(devicesPath);
@@ -120,9 +120,10 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
             for(int j = 0; j<sList.count();j++) {
                 lastLine =  sList.at(j);
 
-                if (lastLine.contains("end", Qt::CaseInsensitive)) {
-                    if(!deviceList.contains(modelItem,Qt::CaseInsensitive))
-                       deviceList.append("include \"/home/user/MyDocs/qtirreco/Devices/" + modelItem + "\"");
+                if (lastLine.contains("end", Qt::CaseInsensitive))
+                    if(!deviceList.contains(modelItem,Qt::CaseInsensitive)) {
+                       deviceList.append("include \"" + devicesPath + modelItem + "\"");
+
                     for(int i= 0; i< deviceList.count();i++) {
                         io << deviceList.at(i)+"\n";
                     }
@@ -158,8 +159,7 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
         }
         else {
               if(remoteStartup) {
-                        QString para = modelItem;
-                        remotestartupdlg = new RemoteStartupDlg(para, this, remoteNames);
+                        remotestartupdlg = new RemoteStartupDlg(modelItem, this, remoteNames);
                         connect(remotestartupdlg,SIGNAL(addButtonToLayoutSignalFromRSD(QString,QString,QString,QString,QStringList,int)),this,SLOT(AddButtonToLayout(QString, QString,QString,QString,QStringList,int)));
                         connect(remotestartupdlg,SIGNAL(remoteCreated(QString)),this,SLOT(enableRemoteNameAdding(QString)));
                         connect(remotestartupdlg,SIGNAL(lwClear()),this,SLOT(clearScreenForNewRemote()));
@@ -167,7 +167,6 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
                         delete remotestartupdlg;
                    }
 
-
               }
 
               this->close();
@@ -175,12 +174,13 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
 }
 void DownloadRemoteDlg::error(int i ,QString string)
 {
-    QMessageBox::warning(this,"Error",string,
+    QMessageBox::warning(this,"Error: "+QString::number(i,10),string,
                                  QMessageBox::NoButton,QMessageBox::NoButton);
 }
 void DownloadRemoteDlg::fault(int i,int j,QString string)
 {
-    QMessageBox::warning(this,"Error",string,
+    Q_UNUSED(j);
+    QMessageBox::warning(this,"Fault: "+QString::number(i,10),string,
                                  QMessageBox::NoButton,QMessageBox::NoButton);
 }
 void DownloadRemoteDlg::AddButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList aCommand, int number)
