@@ -17,8 +17,8 @@ DownloadUserRemoteDlg::DownloadUserRemoteDlg(QWidget *parent) :
 
     client = new QxtXmlRpcClient(this, url);
     connect(client,SIGNAL(finish(int,QVariant)),this,SLOT(processReturnValue(int,QVariant)));
-    connect(client,SIGNAL(networkError(int,QString)),this,SLOT(error(int,QString)));
-    connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString)));
+    connect(client,SIGNAL(networkError(int,QString)),this,SLOT(error(int,QString )));
+    connect(client,SIGNAL(fault(int,int,QString )),this,SLOT(fault(int,int,QString)));
 
     connect(m_ui->listWidget,SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(updateListWidget(QListWidgetItem*)));
 
@@ -55,7 +55,7 @@ void DownloadUserRemoteDlg::processReturnValue(int Id,QVariant data)
         m_ui->listWidget->insertItems(0,sList);
         this->setEnabled(true);
     }
-    if (Id == remoteIdcall) {
+    else if (Id == remoteIdcall) {
         QMap<QString,QVariant> array = data.toMap();
         QVariant categoryV = array.value("category");
         QVariant modelV = array.value("model");
@@ -76,7 +76,7 @@ void DownloadUserRemoteDlg::processReturnValue(int Id,QVariant data)
         m_ui->downloadPushButton->setEnabled(true);
         this->setEnabled(true);
     }
-    if (Id == dataId) {
+    else if (Id == dataId) {
         QMap<QString,QVariant> array = data.toMap();
         QVariant dataVar = array.value("data");
         QString data = dataVar.toString();
@@ -115,7 +115,7 @@ void DownloadUserRemoteDlg::processReturnValue(int Id,QVariant data)
             this->close();
         }
     }
-    if (Id == remoteIds) {
+    else if (Id == remoteIds) {
         remoteIdList.clear();
         versions.clear();
         versionIndex = 0;
@@ -124,7 +124,7 @@ void DownloadUserRemoteDlg::processReturnValue(int Id,QVariant data)
         remoteIdList = data.toStringList();
         this->getRemoteVersionById(remoteIdList.at(versionIndex));
     }
-    if (Id == remoteVersion) {
+    else if (Id == remoteVersion) {
         versionIndex++;
         versions.append(data.toString());
         remoteVersions.insert(data.toString(),remoteId);
@@ -163,12 +163,13 @@ void DownloadUserRemoteDlg::getRemoteVersionById(QString id)
 
 void DownloadUserRemoteDlg::error(int i ,QString string)
 {
-    QMessageBox::warning(this,"Error",""+ string,
+        QMessageBox::warning(this,"Error: "+QString::number(i,10), string,
                      QMessageBox::NoButton,QMessageBox::NoButton);
 }
 void DownloadUserRemoteDlg::fault(int i,int j,QString string)
 {
-    QMessageBox::warning(this,"Fault",""+ string,
+    Q_UNUSED(j);
+    QMessageBox::warning(this,"Fault: "+QString::number(i,10),string,
                      QMessageBox::NoButton,QMessageBox::NoButton);
 }
 void DownloadUserRemoteDlg::updateListWidget(QListWidgetItem* item)
