@@ -21,9 +21,6 @@ LayoutWidget::LayoutWidget(QMainWindow *parent ) : QWidget( parent )
     connect(timer2,SIGNAL(timeout()),this,SLOT(sendIrCommandsSlot2()));
     timer->setInterval(100);
     timer2->setInterval(timeout2);
-    socket->create();
-    bool connected = socket->connect("localhost", 8765);
-    if(!connected) QMessageBox::warning(this,"Socket connection","Socket connection failed!");
 }
 
 LayoutWidget::~LayoutWidget()
@@ -51,6 +48,7 @@ void LayoutWidget::openEditDlg()
 
 void LayoutWidget::editButton(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number, int timeOut)
 {
+     Q_UNUSED(number);
      QPoint position = newButton->pos();
 
      ButtonWidget *pw = new ButtonWidget(this, fileNameUnPressed, fileNamePressed, confFileName, buttonText, commands, timeOut);
@@ -459,8 +457,14 @@ void LayoutWidget::sendIrCommands(QStringList commands)
 {
 
     if(commands.count() < 2) {
+        socket->create();
+        bool connected = socket->connect("localhost", 8765);
+        if(!connected)  QMessageBox::warning(this,"Socket connection","Socket connection with lirc failed! Please try reopening software.");
         const QString command = "SEND_ONCE " +commands.at(0);
         socket->sendSocket(&command);
+        bool disconnect = socket->disconnectSocket();
+        if(disconnect != 0) QMessageBox::warning(this,"Socket connection","Socket disconnection with lirc failed! Please try reopening software.");
+
     }
     else {
         timer2->setInterval(1);
@@ -477,8 +481,13 @@ void LayoutWidget::sendIrCommandsSlot2()
 {
 
     if(timer2Index < copyButton->commandChain.count()) {
+         socket->create();
+         bool connected = socket->connect("localhost", 8765);
+         if(!connected)  QMessageBox::warning(this,"Socket connection","Socket connection with lirc failed! Please try reopening software.");
          const QString command = "SEND_ONCE " +copyButton->commandChain.at(timer2Index);
          socket->sendSocket(&command);
+         bool disconnect = socket->disconnectSocket();
+         if(disconnect != 0) QMessageBox::warning(this,"Socket connection","Socket disconnection with lirc failed! Please try reopening software.");
          timer2Index++;
          timeout2 = copyButton->timeOut;
          timer2->setInterval(timeout2);
