@@ -37,8 +37,6 @@ public:
     void addButton(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, QPoint position, int timeOut);
     //! Sets using mode enabled or disabled.
     void setUseModeEnabled(bool useMode);
-    //! Shows menu.
-    void setButtonsVisible(bool menuButtonsVisible);
     //! Socket for sending Lirc commands.
     Socket *socket;
     //! Vector for all buttons on layout.
@@ -50,8 +48,6 @@ public:
 private:
     //! Boolean to tell if using mode enabled or disabled.
     bool useModeEnabled;
-    //! Boolean to tell if menu buttons visible.
-    bool buttonsVisible;
     //! Background RGB values.
     QString r,g,b;
     //! Remote name for active remote.
@@ -81,9 +77,6 @@ protected:
     void dropEvent(QDropEvent *event);
 
 signals:
-    //! Emitted for QtIrreco to hide or show menu buttons.
-    void showOrHideMenu();
-    void saveFailed();
 
 public slots:
     //! Saves remote to file.
