@@ -167,12 +167,12 @@ void NewButtonDlg::mousePressEvent(QMouseEvent *event)
 void NewButtonDlg::on_addPushButton_clicked()
 {
     CommandChainDlg *ccDlg = new CommandChainDlg(this);
-    connect(ccDlg,SIGNAL(signalAddCommand(QString,QString,QString)),this,SLOT(getCommand(QString,QString,QString)));
+    connect(ccDlg,SIGNAL(signalAddCommand(QString,QString)),this,SLOT(getCommand(QString,QString)));
     ccDlg->exec();
     delete ccDlg;
 }
 
-void NewButtonDlg::getCommand(QString commandName,QString modelName,QString command)
+void NewButtonDlg::getCommand(QString commandName,QString modelName)
 {
     QListWidgetItem *item = new QListWidgetItem();
     item->setText(modelName+ " " + commandName);
