@@ -24,9 +24,19 @@ QtIrreco::QtIrreco(QWidget *parent)
     connect(this,SIGNAL(remoteDeleted()),lw,SLOT(clearScreen()));
 
     useModeEnabled = true;
+    
+    QUrl url;
+    url.setHost("mercury.wipsl.com");
+    url.setPath("/qtirreco/webdb/");
+    url.setPort(80);
 
-   this->checkForRemotes();
-   if(remoteNames->count() != 0) {
+    client = new QxtXmlRpcClient(this, url);
+    connect(client,SIGNAL(finish(int,QVariant)),this,SLOT(processReturnValue(int,QVariant)));
+    connect(client,SIGNAL(networkError(int,QString)),this,SLOT(error(int,QString)));
+    connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString)));
+
+    this->checkForRemotes();
+    if(remoteNames->count() != 0) {
        this->setWindowTitle("QtIrreco:"+activeRemote);
        this->setActiveRemote();
     }
@@ -52,7 +62,7 @@ void QtIrreco::setActiveRemote()
         QTextStream in(&file);
         while (!in.atEnd()) {
             QString line = in.readLine();
-            this->readRemoteFile(line);
+            this->readRemoteFile(line, in.atEnd());
         }
     file.close();
 }
@@ -297,6 +307,7 @@ void QtIrreco::AddButtonToLayout(QString fileNameUnPressed, QString fileNamePres
 }
 void QtIrreco::AddButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number,int timeOut)
 {
+    Q_UNUSED(number);
     lw->addButton(fileNameUnPressed, fileNamePressed, confFileName, buttonText, commands, QPoint(0,0), timeOut);
 }
 
@@ -329,6 +340,7 @@ void QtIrreco::deleteRemote() // Using RenameRemoteDlg class
     rrDlg->setLabelGeometry(150,25,600,50);
     rrDlg->setPushButtonText("Delete");
     rrDlg->setPushButtonGeometry(300,85,200,60);
+    rrDlg->enableButton(true);
     rrDlg->hideLineEdit();
     connect(rrDlg,SIGNAL(deleteRemote()),this,SLOT(deleteActiveRemote()));
     rrDlg->exec();
@@ -464,6 +476,7 @@ void QtIrreco::downloadDB()
     DownloadUserRemoteDlg *downloadDlg = new DownloadUserRemoteDlg(this);
     connect(downloadDlg,SIGNAL(remoteDownloaded(QString)),this,SLOT(addDownloadedRemote(QString)));
     downloadDlg->exec();
+    delete downloadDlg;
 }
 
 void QtIrreco::uploadDB()
@@ -491,7 +504,7 @@ void QtIrreco::showRemote()
     }
 }
 
-void QtIrreco::readRemoteFile(QString line)
+void QtIrreco::readRemoteFile(QString line, bool lastLine)
 {
     if(line.contains("Background: ",Qt::CaseInsensitive)) {
         line = line.trimmed();
@@ -585,15 +598,17 @@ void QtIrreco::readRemoteFile(QString line)
         commandChain.clear();
     }
 
-    // button reading ends
-    bool ok;
-    r = red.toInt(&ok,10);
-    g = green.toInt(&ok,10);
-    b = blue.toInt(&ok,10);
+    if(lastLine) {
+        // button reading ends
+        bool ok;
+        r = red.toInt(&ok,10);
+        g = green.toInt(&ok,10);
+        b = blue.toInt(&ok,10);
 
-    emit rgbToLw(r,g,b);
-    QColor rgb(r,g,b);
-    this->changeBackground(backgroundName,rgb);
+        emit rgbToLw(r,g,b);
+        QColor rgb(r,g,b);
+        this->changeBackground(backgroundName,rgb);
+    }
 }
 
 void QtIrreco::process_line(QString line)
@@ -635,16 +650,21 @@ void QtIrreco::changeBackground()
         lw->setAutoFillBackground(true);
     }
     else {
+
         QPixmap backImage = bg->returnBackgroundPixmap();
         QPixmap backColor = bg->returnBackgroundPixmapColor();
 
-        palette.setBrush(QPalette::Window,backColor);
-        this->setPalette(palette);
-        this->setAutoFillBackground(true);
+        if(!backColor.isNull()) {
+            palette.setBrush(QPalette::Window,backColor);
+            this->setPalette(palette);
+            this->setAutoFillBackground(true);
+        }
 
-        palette.setBrush(QPalette::Window, backImage);
-        lw->setPalette(palette);
-        lw->setAutoFillBackground(true);
+        if(!backImage.isNull()) {
+            palette.setBrush(QPalette::Window, backImage);
+            lw->setPalette(palette);
+            lw->setAutoFillBackground(true);
+        }
     }
 }
 
@@ -662,18 +682,22 @@ void QtIrreco::changeBackground(QString backgroundName, QColor backgroundColor)
         lw->setPalette(palette);
         lw->setAutoFillBackground(true);
     }
+
     else {
 
-        palette.setColor(QPalette::Window,backgroundColor);
-        this->setPalette(palette);
-        this->setAutoFillBackground(true);
+        if(backgroundColor.isValid()) {
+            palette.setColor(QPalette::Window,backgroundColor);
+            this->setPalette(palette);
+            this->setAutoFillBackground(true);
+        }
 
         QPixmap backImage(backgroundName);
-        backImage = backImage.scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation);
+        if(!backImage.isNull()) {
 
-        palette.setBrush(QPalette::Window, backImage);
-        lw->setPalette(palette);
-        lw->setAutoFillBackground(true);
+            palette.setBrush(QPalette::Window, backImage.scaled(800,424,Qt::IgnoreAspectRatio,Qt::FastTransformation));
+            lw->setPalette(palette);
+            lw->setAutoFillBackground(true);
+        }
     }
 }
 void QtIrreco::initMenu()
@@ -828,16 +852,6 @@ void QtIrreco::checkThemesForRemote(QString remoteFile)
         }
     }
 
-    QUrl url;
-    url.setHost("mercury.wipsl.com");
-    url.setPath("/qtirreco/webdb/");
-    url.setPort(80);
-
-    client = new QxtXmlRpcClient(this, url);
-    connect(client,SIGNAL(finish(int,QVariant)),this,SLOT(processReturnValue(int,QVariant)));
-    connect(client,SIGNAL(networkError(int,QString)),this,SLOT(error(int,QString)));
-    connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString)));
-
     if(themesForRemote.isEmpty()) {
         lw->setActiveRemoteName(activeRemote);
         this->writeRemoteChanges();
@@ -943,16 +957,6 @@ void QtIrreco::checkLircFilesForRemote(QString remoteFile)
         }
     }
 
-    QUrl url;
-    url.setHost("mercury.wipsl.com");
-    url.setPath("/qtirreco/webdb/");
-    url.setPort(80);
-
-    client = new QxtXmlRpcClient(this, url);
-    connect(client,SIGNAL(finish(int,QVariant)),this,SLOT(processReturnValue(int,QVariant)));
-    connect(client,SIGNAL(networkError(int,QString)),this,SLOT(error(int,QString)));
-    connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString)));
-
     QList<QVariant> params;
     for(callCounter=0;callCounter<lircConfs.length();callCounter++) {
         QMessageBox::information(this,"Lirc configuration","Configuration " + lircConfs.at(callCounter) + " downloaded succesfully!",
@@ -974,7 +978,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         themeDatas = client->call("getThemeById",params);
 
     }
-    if (Id == themeDatas) {
+    else if (Id == themeDatas) {
         QMap<QString,QVariant> array = data.toMap();
         QVariant name = array.value("name");
         themeNameFromConf = name.toString();
@@ -996,12 +1000,12 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         params.append(downloadId);
         themeButtonIds = client->call("getButtons",params);
     }
-    if (Id == themeButtonIds) {
+    else if (Id == themeButtonIds) {
         dbButtonIdsList = sList;
         this->getThemeButtonsByIds();
 
     }
-    if (Id == buttonData) { // COPY BUTTONS AND MAKE FOLDERS
+    else if (Id == buttonData) { // COPY BUTTONS AND MAKE FOLDERS
 
         progressValue += 100 / (dbButtonIdsList.count()+2);
         emit progressState(progressValue);
@@ -1060,7 +1064,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         // Get button imagedatas and make .png files
         this->getUnpressedImage();
     }
-    if (Id == unpressedToFile)  { // Name always unpressed.png
+    else if (Id == unpressedToFile)  { // Name always unpressed.png
         QPixmap previewPix(128,128);
         QByteArray pb = data.toByteArray();
         QByteArray ba = QByteArray::fromBase64(pb);
@@ -1068,7 +1072,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         previewPix.save(buttonPath+"/unpressed.png","PNG");
         this->getPressedImage();
     }
-    if (Id == pressedToFile) { // Name always pressed.png
+    else if (Id == pressedToFile) { // Name always pressed.png
         QPixmap previewPix(128,128);
         QByteArray pb = data.toByteArray();
         QByteArray ba = QByteArray::fromBase64(pb);
@@ -1076,7 +1080,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         previewPix.save(buttonPath+"/pressed.png","PNG");
         this->getThemeButtonsByIds();
     }
-    if (Id == themeBgIds) {
+    else if (Id == themeBgIds) {
         dbBackgroundIdsList = sList;
         if(dbBackgroundIdsList.count() > 0 && !dbBackgroundIdsList.contains("0")) {
             this->setWindowTitle("Downloading theme backgrounds...");
@@ -1087,7 +1091,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
             this->downloadTheme();
         }
     }
-    if (Id == bgData) {
+    else if (Id == bgData) {
         themeBgIndex++;
         progressValue += 100 / (dbButtonIdsList.count()+2);
         emit progressState(progressValue);
@@ -1112,7 +1116,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         // Get background imagedatas and make .png files
         this->getBgImage();
     }
-    if (Id == bgToFile) {
+    else if (Id == bgToFile) {
         QPixmap previewPix(128,128);
         QByteArray pb = data.toByteArray();
         QByteArray ba = QByteArray::fromBase64(pb);
@@ -1120,7 +1124,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         previewPix.save(bgPath+"/image.png","PNG");
         this->getThemeBackgroundsByIds();
     }
-    if (Id == fileId) {
+    else if (Id == fileId) {
         if(!QFile::exists(devicesPath + lircConfs.at(callCounter-1))) {
             QFile deviceFile(devicesPath +lircConfs.at(callCounter-1));
             deviceFile.open(QIODevice::WriteOnly | QIODevice::Text);
@@ -1146,7 +1150,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
 
                 if (lastLine.contains("end", Qt::CaseInsensitive)) {
                     if(!deviceList.contains(lircConfs.at(callCounter-1),Qt::CaseInsensitive))
-                       deviceList.append("include \"/home/user/MyDocs/qtirreco/Devices/" + lircConfs.at(callCounter-1) + "\"");
+                       deviceList.append("include \"" + devicesPath + lircConfs.at(callCounter-1) + "\"");
 
                     for(int i= 0; i< deviceList.count();i++)
                         io << deviceList.at(i)+"\n";
@@ -1168,13 +1172,14 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
 
 void QtIrreco::error(int i ,QString string)
 {
-    QMessageBox::warning(this,"Error",string,
+    QMessageBox::warning(this,"Error: "+QString::number(i,10),string,
                                  QMessageBox::NoButton,QMessageBox::NoButton);
 }
 
 void QtIrreco::fault(int i,int j,QString string)
 {
-    QMessageBox::warning(this,"Fault",string,
+    Q_UNUSED(j);
+    QMessageBox::warning(this,"Fault: "+QString::number(i,10), string,
                                  QMessageBox::NoButton,QMessageBox::NoButton);
 }
 void QtIrreco::getUnpressedImage()
