@@ -92,11 +92,12 @@ void RegisterDlg::processReturnValue(int Id,QVariant data)
 }
 void RegisterDlg::error(int i ,QString string)
 {
-    QMessageBox::warning(this,"Error. ",""+ string,
+    QMessageBox::warning(this,"Error: "+QString::number(i,10), string,
                      QMessageBox::NoButton,QMessageBox::NoButton);
 }
 void RegisterDlg::fault(int i,int j,QString string)
 {
-    QMessageBox::warning(this,"Fault. ",""+ string,
+    Q_UNUSED(j);
+    QMessageBox::warning(this,"Fault: "+QString::number(i,10),string,
                      QMessageBox::NoButton,QMessageBox::NoButton);
 }
