@@ -8,6 +8,7 @@
 #include <QListWidgetItem>
 #include <QMessageBox>
 #include "definitions.h"
+#include "thememanager.h"
 
 namespace Ui {
     class RemoteStartupDlg;
@@ -48,14 +49,26 @@ private:
     int buttonsCount;
     //! Contains remote names
     QStringList *remoteNames;
+    //! Name for theme to be used creating buttons.
+    QString themeUsed;
+    //! If custom theme selected open theme manager.
+    bool customTheme;
+    //! Check theme buttons and button text for matches to make buttons with proper image.
+    void setButtonPath(const QString &buttonText);
+    //! Button paths.
+    QString fileNameUnpressed;
+    QString fileNamePressed;
+    QString confFileName;
 
  private slots:
     //! Emits signal to LayoutWidget to clear screen and make buttons.
+    void on_selectThemeButton_clicked();
     void on_pushButton_clicked();
     //! Adds button to selected list.
     void itemClicked(QListWidgetItem* item);
     //! Removes button from selected list.
     void removeFromSelectedList(QListWidgetItem* item);
+    void setThemeName(const QString &themeName);
     
  signals:
     //! Signal for LayoutWidget to make button.
