@@ -6,6 +6,10 @@ ThemeCreatorDlg::ThemeCreatorDlg(QWidget *parent) :
     m_ui(new Ui::ThemeCreatorDlg)
 {
     m_ui->setupUi(this);
+    m_ui->textEdit->setProperty("FingerScrollable", true);
+    m_ui->scrollArea->setProperty("FingerScrollable", true);
+    m_ui->scrollArea_2->setProperty("FingerScrollable", true);
+
     m_ui->saveThemePushButton->setDisabled(true);
     m_ui->editButton->setDisabled(true);
     m_ui->deleteButton->setDisabled(true);
